@@ -1,3 +1,4 @@
+local({
 jet.colors = colorRampPalette(c("#00007F", "blue",
     "#007FFF", "cyan", "#7FFF7F", "yellow", "#FF7F00", "red",
     "#7F0000"))
@@ -17,3 +18,4 @@ for (k in 1:20) {
     image(X[, , k])
     ani.pause(0.01)
 }
+})
