@@ -4,9 +4,9 @@
 library(animation)
 saveHTML({
    ## a custom file list on the Internet
-   extList = c('http://yihui.name/cn/wp-content/uploads/1192203237_1.jpg',
-               'http://yihui.name/cn/wp-content/uploads/1192203252_1.jpg',
-               'http://yihui.name/cn/wp-content/uploads/1191914651_1.jpg')
+   extList = c('http://i.imgur.com/rJ7xF.jpg',
+               'http://i.imgur.com/Lyr9o.jpg',
+               'http://i.imgur.com/18Qrb.jpg')
    for (i in 1:length(extList)) {
        download.file(url = extList[i], destfile = sprintf(ani.options("img.fmt"), i), mode = 'wb')
    }
